@@ -54,8 +54,8 @@ def main():
         in_paths = [opts.update]
         out_path = opts.update
     else:
-        in_paths = opt.in_paths
-        out_path = opt.out_path
+        in_paths = opts.in_paths
+        out_path = opts.out_path
 
     for in_path in in_paths:
         d = json.load(open(in_path, "r"))
@@ -91,7 +91,7 @@ def main():
             if opts.reload: schedule = runlist
             else: schedule = [cmd for cmd in runlist if cmd.name not in rec["results"]]
 
-            log("Checking out revision %s [%d/%d]", comm["commit"], idx+1, len(commits))
+            log("Checking out revision %s [%d/%d]", comm["commit"], idx+1, len(process))
             git_checkout(git_new, sha1)
 
             for cmd in schedule:
